NAME
Jifty::View::Declare::BaseClass
DESCRIPTION
This class provides a baseclass for your Template::Declare derived view classes.
METHODS
show templatename arguments
Render a Template::Declare template.
The path as passed in the fragment request data structure was used verbatim in the dispatcher and other locations. This possibly allowed requests to walk around ACLs by requesting '/some/safe/place/../../../dangerous' as a fragment.
The REST plugin would let you call any method on the model.
Jifty::View::Declare::BaseClass
This class provides a baseclass for your Template::Declare derived view classes.
Render a Template::Declare template.
To install Jifty, copy and paste the appropriate command in to your terminal.
cpanm Jifty
perl -MCPAN -e shell
install Jifty
For more information on module installation, please visit the detailed CPAN module installation guide.
| Global | |
|---|---|
| s | Focus search bar |
| ? | Bring up this help dialog |
| GitHub | |
|---|---|
| g p | Go to pull requests |
| g i | Go to GitHub issues (only if GitHub is preferred repository) |
| POD | |
|---|---|
| g a | Go to author |
| g c | Go to changes |
| g i | Go to issues |
| g d | Go to dist |
| g r | Go to repository/SCM |
| g s | Go to source |
| g b | Go to file browse |
| Search terms |
|---|
| module: (e.g. module:Plugin) |
| distribution: (e.g. distribution:Dancer auth) |
| author: (e.g. author:SONGMU Redis) |
| version: (e.g. version:1.00) |